;; Generated package description from kind-icon.el  -*- no-byte-compile: t -*-
(define-package "kind-icon" "0.2.1" "Completion kind icons" '((emacs "27.1") (svg-lib "0.2.8")) :commit "d432c947b218414621c9673b4ba8910ac129eef6" :authors '(("J.D. Smith" . "jdtsmith@gmail.com")) :maintainer '("J.D. Smith" . "jdtsmith@gmail.com") :keywords '("completion" "convenience") :url "https://github.com/jdtsmith/kind-icon")
